==> huaweicloudsdkeip-3.1.18-py2.py3-none-any.whl: huaweicloudsdkeip/v2/model/bw_change_to_period_req.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BwChangeToPeriodReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'bandwidth_ids': 'list[str]',
        'extend_param': 'object'
    }

    attribute_map = {
        'bandwidth_ids': 'bandwidth_ids',
        'extend_param': 'extendParam'
    }

    def __init__(self, bandwidth_ids=None, extend_param=None):
        """BwChangeToPeriodReq

        The model defined in huaweicloud sdk

        :param bandwidth_ids: 待按需转包带宽列表 
        :type bandwidth_ids: list[str]
        :param extend_param: 按需转包周期参数
        :type extend_param: object
        """
        
        

        self._bandwidth_ids = None
        self._extend_param = None
        self.discriminator = None

        self.bandwidth_ids = bandwidth_ids
        self.extend_param = extend_param

    @property
    def bandwidth_ids(self):
        """Gets the bandwidth_ids of this BwChangeToPeriodReq.

        待按需转包带宽列表 

        :return: The bandwidth_ids of this BwChangeToPeriodReq.
        :rtype: list[str]
        """
        return self._bandwidth_ids

    @bandwidth_ids.setter
    def bandwidth_ids(self, bandwidth_ids):
        """Sets the bandwidth_ids of this BwChangeToPeriodReq.

        待按需转包带宽列表 

        :param bandwidth_ids: The bandwidth_ids of this BwChangeToPeriodReq.
        :type bandwidth_ids: list[str]
        """
        self._bandwidth_ids = bandwidth_ids

    @property
    def extend_param(self):
        """Gets the extend_param of this BwChangeToPeriodReq.

        按需转包周期参数

        :return: The extend_param of this BwChangeToPeriodReq.
        :rtype: object
        """
        return self._extend_param

    @extend_param.setter
    def extend_param(self, extend_param):
        """Sets the extend_param of this BwChangeToPeriodReq.

        按需转包周期参数

        :param extend_param: The extend_param of this BwChangeToPeriodReq.
        :type extend_param: object
        """
        self._extend_param = extend_param

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BwChangeToPeriodReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeip-3.1.37-py2.py3-none-any.whl: huaweicloudsdkeip/v2/model/bw_change_to_period_req.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BwChangeToPeriodReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'bandwidth_ids': 'list[str]',
        'extend_param': 'CreatePrePaidPublicipExtendParamOption'
    }

    attribute_map = {
        'bandwidth_ids': 'bandwidth_ids',
        'extend_param': 'extendParam'
    }

    def __init__(self, bandwidth_ids=None, extend_param=None):
        """BwChangeToPeriodReq

        The model defined in huaweicloud sdk

        :param bandwidth_ids: 待按需转包带宽列表 
        :type bandwidth_ids: list[str]
        :param extend_param: 
        :type extend_param: :class:`huaweicloudsdkeip.v2.CreatePrePaidPublicipExtendParamOption`
        """
        
        

        self._bandwidth_ids = None
        self._extend_param = None
        self.discriminator = None

        self.bandwidth_ids = bandwidth_ids
        self.extend_param = extend_param

    @property
    def bandwidth_ids(self):
        """Gets the bandwidth_ids of this BwChangeToPeriodReq.

        待按需转包带宽列表 

        :return: The bandwidth_ids of this BwChangeToPeriodReq.
        :rtype: list[str]
        """
        return self._bandwidth_ids

    @bandwidth_ids.setter
    def bandwidth_ids(self, bandwidth_ids):
        """Sets the bandwidth_ids of this BwChangeToPeriodReq.

        待按需转包带宽列表 

        :param bandwidth_ids: The bandwidth_ids of this BwChangeToPeriodReq.
        :type bandwidth_ids: list[str]
        """
        self._bandwidth_ids = bandwidth_ids

    @property
    def extend_param(self):
        """Gets the extend_param of this BwChangeToPeriodReq.

        :return: The extend_param of this BwChangeToPeriodReq.
        :rtype: :class:`huaweicloudsdkeip.v2.CreatePrePaidPublicipExtendParamOption`
        """
        return self._extend_param

    @extend_param.setter
    def extend_param(self, extend_param):
        """Sets the extend_param of this BwChangeToPeriodReq.

        :param extend_param: The extend_param of this BwChangeToPeriodReq.
        :type extend_param: :class:`huaweicloudsdkeip.v2.CreatePrePaidPublicipExtendParamOption`
        """
        self._extend_param = extend_param

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BwChangeToPeriodReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
